# -*- coding: utf-8 -*-

from rest_framework import serializers
from thx.api.serializers import ThuxCreateSerializerMixin, ThuxUpdateSerializerMixin

from ... import models
from apps.role.core.serializers import ThuxRoleSerializerMixin


# LITE INFO SERIALIZER
class CarriageLiteInfoSerializer(serializers.ModelSerializer):
    class Meta:
        model = models.Carriage
        fields = ['code', 'name']


# CARRIAGE
class CarriageSerializer(ThuxRoleSerializerMixin, serializers.ModelSerializer):
    class Meta:
        ref_name = 'v1_carriage_carriage'
        model = models.Carriage
        fields = '__all__'


class CarriageCreateSerializer(
    ThuxRoleSerializerMixin, ThuxCreateSerializerMixin, serializers.ModelSerializer
):

    def to_representation(self, instance):
        return CarriageSerializer(instance, context=self.context).data

    class Meta:
        ref_name = 'v1_carriage_carriage_create'
        model = models.Carriage
        fields = '__all__'


class CarriageUpdateSerializer(
    ThuxRoleSerializerMixin, ThuxUpdateSerializerMixin, serializers.ModelSerializer
):

    def to_representation(self, instance):
        return CarriageSerializer(instance, context=self.context).data

    class Meta:
        ref_name = 'v1_carriage_carriage_update'
        model = models.Carriage
        fields = '__all__'


class CarriageEnableSerializer(ThuxRoleSerializerMixin, serializers.ModelSerializer):

    def update(self, instance, validated_data):
        instance.status = 1
        instance.save()
        return instance

    class Meta:
        ref_name = 'v1_carriage_carriage_enable'
        model = models.Carriage
        fields = '__all__'

    def to_representation(self, instance):
        return CarriageSerializer(instance, context=self.context).data


class CarriageDisableSerializer(ThuxRoleSerializerMixin, serializers.ModelSerializer):

    def update(self, instance, validated_data):
        instance.status = 0
        instance.save()
        return instance

    class Meta:
        ref_name = 'v1_carriage_carriage_disable'
        model = models.Carriage
        fields = '__all__'

    def to_representation(self, instance):
        return CarriageSerializer(instance, context=self.context).data


# DELIVERY
class DeliverySerializer(ThuxRoleSerializerMixin, serializers.ModelSerializer):
    carriage = CarriageLiteInfoSerializer()

    class Meta:
        ref_name = 'v1_carriage_delivery'
        model = models.Delivery
        fields = '__all__'

    def get_field_names(self, *args, **kwargs):
        fields = super().get_field_names(*args, **kwargs)
        fields.append('get_transport_by_display')
        return fields


class DeliveryCreateSerializer(
    ThuxRoleSerializerMixin, ThuxCreateSerializerMixin, serializers.ModelSerializer
):

    def to_representation(self, instance):
        return DeliverySerializer(instance, context=self.context).data

    class Meta:
        ref_name = 'v1_carriage_delivery_create'
        model = models.Delivery
        fields = '__all__'


class DeliveryUpdateSerializer(
    ThuxRoleSerializerMixin, ThuxUpdateSerializerMixin, serializers.ModelSerializer
):

    def to_representation(self, instance):
        return DeliverySerializer(instance, context=self.context).data

    class Meta:
        ref_name = 'v1_carriage_delivery_update'
        model = models.Delivery
        fields = '__all__'


class DeliveryEnableSerializer(ThuxRoleSerializerMixin, serializers.ModelSerializer):

    def update(self, instance, validated_data):
        instance.status = 1
        instance.save()
        return instance

    class Meta:
        ref_name = 'v1_carriage_delivery_enable'
        model = models.Delivery
        fields = '__all__'

    def to_representation(self, instance):
        return DeliverySerializer(instance, context=self.context).data


class DeliveryDisableSerializer(ThuxRoleSerializerMixin, serializers.ModelSerializer):

    def update(self, instance, validated_data):
        instance.status = 0
        instance.save()
        return instance

    class Meta:
        ref_name = 'v1_carriage_delivery_disable'
        model = models.Delivery
        fields = '__all__'

    def to_representation(self, instance):
        return DeliverySerializer(instance, context=self.context).data
