# -*- coding: utf-8 -*-

from rest_framework import viewsets, status
from rest_framework.decorators import action
from rest_framework.response import Response

from thx.api.views import ThuxViewMixin

from . import serializers
from ... import models
from apps.role.core.views import ThuxRoleViewSetMixin
from django.conf import settings


# CARRIAGE
class CarriageViewSet(ThuxRoleViewSetMixin, ThuxViewMixin, viewsets.ModelViewSet):
    queryset = models.Carriage.objects.all()
    serializer_class = serializers.CarriageSerializer

    def get_queryset(self):
        user = self.request.user
        # profile = self.kwargs.get('profile')
        return super().get_queryset()

    def check_permissions(self, request):
        user = self.request.user
        # profile = self.kwargs.get('profile')
        return super().check_permissions(request)

    def get_serializer_class(self):
        action = self.action.replace('-', ' ').replace('_', ' ').title().replace(' ', '')
        serializer = getattr(serializers, f'Carriage{action}Serializer', None)
        if serializer:
            return serializer
        return super().get_serializer_class()

    @action(methods=['patch'], detail=True)
    def enable(self, request, **filters):
        return super().partial_update(request)

    @action(methods=['patch'], detail=True)
    def disable(self, request, **filters):
        return super().partial_update(request)


# DELIVERY
class DeliveryViewSet(ThuxRoleViewSetMixin, ThuxViewMixin, viewsets.ModelViewSet):
    queryset = models.Delivery.objects.all()
    serializer_class = serializers.DeliverySerializer

    def get_queryset(self):
        user = self.request.user
        # profile = self.kwargs.get('profile')
        qs = super().get_queryset()
        return qs

    def check_permissions(self, request):
        user = self.request.user
        # profile = self.kwargs.get('profile')
        super().check_permissions(request)

    def get_serializer_class(self):
        action = self.action.replace('-', ' ').replace('_', ' ').title().replace(' ', '')
        serializer = getattr(serializers, f'Delivery{action}Serializer', None)
        if serializer:
            return serializer
        return super().get_serializer_class()

    @action(methods=['patch'], detail=True)
    def enable(self, request, **filters):
        return super().partial_update(request)

    @action(methods=['patch'], detail=True)
    def disable(self, request, **filters):
        return super().partial_update(request)

    @action(methods=['get'], detail=False, url_path='transport-by-options')
    def transport_by_options(self, request, **filters):
        return Response(data=settings.CARRIAGE_TRANSPORTBY_DEF, status=status.HTTP_200_OK)
